@@ -23,14 +23,11 @@ import jsii
 import jsii.compat
 import publication
 
+from ._jsii import *
+
 import aws_cdk.aws_ec2
 import aws_cdk.aws_elasticloadbalancingv2
-import aws_cdk.aws_iam
 import aws_cdk.aws_lambda
-import aws_cdk.core
-import constructs
-
-from ._jsii import *
 
 
 @jsii.implements(aws_cdk.aws_elasticloadbalancingv2.IApplicationLoadBalancerTarget, aws_cdk.aws_elasticloadbalancingv2.INetworkLoadBalancerTarget)
